@@ -713,6 +713,8 @@ def TeluguTamilZha(Strng):
 
 def TeluguTamilRra(Strng):
     Strng = Strng.replace('ఱ్ఱ', 'ౘ్ౘ')
+    Strng = Strng.replace('ట్ర', 'ౘ్ౘ')
+    Strng = Strng.replace('ండ్ర','న్ఱ')
 
     return Strng
 
@@ -1314,6 +1316,21 @@ def LimbuDevanagariConvention(Strng):
 
     return Strng
 
+def NandinagariPrishtamatra(Strng, reverse = False):
+    if not reverse:
+        Strng = Strng.replace('𑧚','𑧤')
+        Strng = Strng.replace('𑧛','𑧤𑧚')
+        Strng = Strng.replace('𑧜','𑧤𑧑')
+        Strng = Strng.replace('𑧝','𑧤𑧜')
+    else:
+        Strng = Strng.replace('𑧤𑧚', '𑧛')
+        Strng = Strng.replace('𑧤𑧑', '𑧜')
+        Strng = Strng.replace('𑧤𑧜', '𑧝')
+        Strng = Strng.replace('𑧤', '𑧚')
+
+
+    return Strng
+
 def DevanagariPrishtamatra(Strng, reverse = False):
     if not reverse:
         Strng = Strng.replace('े','ॎ')
